# [Quick Start](@id quickstart)

This section describes how you can set up your demos easily in _five lines of codes_.

## Manage your demo files

The rules of demo management are super simple:

* you need one demo page to hold all the demo files
* a [demo page](@ref concepts_page) has several [demo sections](@ref concepts_section)
* a demo section either
    * has other demo sections as nested subsections, or,
    * has the [demo files](@ref concepts_card).

In the following example:

* we have one demo page: "quickstart" ---> The current page
* "quickstart" has one demo section: "usage example"
* "usage example" has two demo subsections: "markdown" and "julia"
  * "markdown" section holds all markdown demos
  * "julia" section holds all julia demos
* "assets" folders are ignored by `DemoCards.jl`
* "index.md" is where all demo cards are organized in
* "config.json" are configuration files

```text
docs/quickstart
├── index.md
└── usage_example
    ├── basics
    │   ├── assets
    │   ├── config.json
    │   ├── configure_card.md
    │   ├── configure_sec_and_page.md
    │   └── simple_markdown_demo.md
    ├── config.json
    └── julia demos
        ├── 1.julia_demo.jl
        ├── 2.cover_on_the_fly.jl
        └── assets
```

```@setup simplest_demopage
using DemoCards
using DemoCards: DemoPage
```

Democards can read the demo structure from your folder structure:

```@repl simplest_demopage
cd("../../../..") do
    DemoPage("docs/quickstart")
end
```

## Deploy your demo page

Deployment is also very simple:

1. load a theme using `cardtheme`
2. create a demopage using `makedemos`
3. pass the results to `Documenter.jl`
4. postprocess demos generated by Documenter

```julia
theme = cardtheme()
demopage, postprocess_cb = makedemos("demos") # relative path to docs/

format = Documenter.HTML(edit_branch = "master",
                         assets = [theme, ])
makedocs(format = format,
         pages = [
            "Home" => "index.md",
            "Examples" => demopage,
         ],
         sitename = "Awesome demos")

postprocess_cb()
```

!!! info

    🚧 `cardtheme` is currrently at its draft stage. It simply copies an
    existing css file and returns you a path to it.

After it's set up, you can now focus on contributing more demos and leave
other works to `DemoCards.jl`.

Here's the generated democards! You can read it one by one to have a direct
experience on how things are managed in `DemoCards.jl`.

---

{{{democards}}}

---

## What DemoCards.jl does

The pipeline of [`makedemos`](@ref DemoCards.makedemos) is:

1. analyze the structure of your demo folder and extracts supplementary configuration information
2. copy "`assets`" folder without processing
3. preprocess demo files and save it
4. process and save cover images
5. generate a postprocessing callback function

Since all files are generated to `docs/src`, the next step is to leave everything else
to `Documenter.jl` 😃

!!! tip

    By default, `makedemos` generates all the necessary files to `docs/src/democards`,
    so it's recommended to add it to the `.gitignore` of your project.

For advanced usage of `DemoCards.jl`, you need to understand the core [concepts](@ref concepts) of it.

## Before you start

!!! warning

    It's better to save your demo files outside `docs/src`.

    If you store all your source demo files in `docs/src`, e.g., `docs/src/demos`,
    `DemoCards.jl` will make a copy of it in `docs/src/democards`. This means
    `Documenter.jl` will copy and process the same files _twice_.

!!! warning

    Currently, there's no guarantee that this function works for untypical
    documentation folder structure. By the name **typical**, it is:

    ```julia
    .
    ├── Project.toml
    ├── docs
    │   ├── demos # manage your demos outside docs/src
    │   ├── make.jl
    │   ├── Project.toml
    │   └── src
    ├── src
    └── test
    ```